@@ -1,36 +1,35 @@
 package Email::Sender::Failure::Permanent;
-BEGIN {
-  $Email::Sender::Failure::Permanent::VERSION = '0.102370';
-}
-use Moose;
-extends 'Email::Sender::Failure';
 # ABSTRACT: a permanent delivery failure
+$Email::Sender::Failure::Permanent::VERSION = '1.300035';
+use Moo;
+extends 'Email::Sender::Failure';
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Failure::Permanent - a permanent delivery failure
 
 =head1 VERSION
 
-version 0.102370
+version 1.300035
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2020 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
