@@ -1,6 +1,6 @@
 package Email::Sender::Role::HasMessage;
 # ABSTRACT: an object that has a message
-$Email::Sender::Role::HasMessage::VERSION = '1.300034';
+$Email::Sender::Role::HasMessage::VERSION = '1.300035';
 use Moo::Role;
 
 #pod =attr message
@@ -29,7 +29,7 @@ Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 1.300034
+version 1.300035
 
 =head1 ATTRIBUTES
 
@@ -39,11 +39,11 @@ This attribute is a message associated with the object.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2020 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
