@@ -1,6 +1,6 @@
 package Email::Sender::Success;
 # ABSTRACT: the result of successfully sending mail
-$Email::Sender::Success::VERSION = '1.300018';
+$Email::Sender::Success::VERSION = '1.300035';
 use Moo;
 
 #pod =head1 DESCRIPTION
@@ -25,7 +25,7 @@ Email::Sender::Success - the result of successfully sending mail
 
 =head1 VERSION
 
-version 1.300018
+version 1.300035
 
 =head1 DESCRIPTION
 
@@ -34,11 +34,11 @@ successfully sent.  Unless extended, it has no properties of its own.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2020 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
