@@ -1,17 +1,29 @@
 package Email::Sender::Transport::Sendmail;
-BEGIN {
-  $Email::Sender::Transport::Sendmail::VERSION = '0.102370';
-}
-use Moose;
-with 'Email::Sender::Transport';
 # ABSTRACT: send mail via sendmail(1)
+$Email::Sender::Transport::Sendmail::VERSION = '1.300035';
+use Moo;
+with 'Email::Sender::Transport';
 
+use MooX::Types::MooseLike::Base qw(Str);
+
+#pod =head2 DESCRIPTION
+#pod
+#pod This transport sends mail by piping it to the F<sendmail> command.  If the
+#pod location of the F<sendmail> command is not provided in the constructor (see
+#pod below) then the library will look for an executable file called F<sendmail> in
+#pod the path.
+#pod
+#pod To specify the location of sendmail:
+#pod
+#pod   my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
+#pod
+#pod =cut
 
 use File::Spec ();
 
 has 'sendmail' => (
   is  => 'ro',
-  isa => 'Str',
+  isa => Str,
   required => 1,
   lazy     => 1,
   default  => sub {
@@ -57,8 +69,8 @@ sub _sendmail_pipe {
   my $prog = $self->sendmail;
 
   my ($first, @args) = $^O eq 'MSWin32'
-           ? qq(| "$prog" -f $envelope->{from} @{$envelope->{to}})
-           : (q{|-}, $prog, '-f', $envelope->{from}, @{$envelope->{to}});
+           ? qq(| "$prog" -i -f $envelope->{from} @{$envelope->{to}})
+           : (q{|-}, $prog, '-i', '-f', $envelope->{from}, '--', @{$envelope->{to}});
 
   no warnings 'exec'; ## no critic
   my $pipe;
@@ -73,7 +85,10 @@ sub send_email {
 
   my $pipe = $self->_sendmail_pipe($envelope);
 
-  print $pipe $email->as_string
+  my $string = $email->as_string;
+  $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
+
+  print $pipe $string
     or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
 
   close $pipe
@@ -82,20 +97,22 @@ sub send_email {
   return $self->success;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 0.102370
+version 1.300035
 
 =head2 DESCRIPTION
 
@@ -110,14 +127,13 @@ To specify the location of sendmail:
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2020 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
